# Flint

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

## Table of contents

```{toctree}
:maxdepth: 1
installation.md
quickstart.md
about.md
data.md
config.md
flagging.md
masking.md
source_finding.md
predict.md
contributions.md
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
